@@ -99,18 +99,22 @@ guint i;
 	flt->wording = NULL;
 	flt->tag = NULL;
 
-	flt->last_tab = 0;
+	*flt->last_tab = '\0';
 }
 
 
 void filter_default_all_set(Filter *flt)
 {
+GHashTableIter iter;
+gpointer key, value;
 gint i;
 
 	DB( g_print("(filter) reset %p\n", flt) );
 
 	filter_clear(flt);
 
+	flt->nbdaysfuture = 0;
+
 	flt->range  = FLT_RANGE_LAST12MONTHS;
 	flt->type   = FLT_TYPE_ALL;
 	flt->status = FLT_STATUS_ALL;
@@ -125,6 +129,30 @@ gint i;
 
 	filter_preset_daterange_set(flt, flt->range, 0);
 
+	// set all account
+	g_hash_table_iter_init (&iter, GLOBALS->h_acc);
+	while (g_hash_table_iter_next (&iter, &key, &value))
+	{
+	Account *item = value;
+		item->filter = TRUE;
+	}
+
+	// set all payee
+	g_hash_table_iter_init (&iter, GLOBALS->h_pay);
+	while (g_hash_table_iter_next (&iter, &key, &value))
+	{
+	Payee *item = value;
+		item->filter = TRUE;
+	}
+
+	// set all payee
+	g_hash_table_iter_init (&iter, GLOBALS->h_cat);
+	while (g_hash_table_iter_next (&iter, &key, &value))
+	{
+	Category *item = value;
+		item->filter = TRUE;
+	}
+
 }
 
 
@@ -192,8 +220,11 @@ void filter_preset_daterange_add_futuregap(Filter *filter, gint nbdays)
 {
 
 	if( nbdays <= 0 )
+	{
+		filter->nbdaysfuture = 0;
 		return;
-		
+	}
+	
 	switch( filter->range )
 	{
 		case FLT_RANGE_THISMONTH:
@@ -203,7 +234,7 @@ void filter_preset_daterange_add_futuregap(Filter *filter, gint nbdays)
 		case FLT_RANGE_LAST60DAYS:
 		case FLT_RANGE_LAST90DAYS:
 		case FLT_RANGE_LAST12MONTHS:
-			filter->maxdate += nbdays;
+			filter->nbdaysfuture = nbdays;
 			break;
 	}
 
@@ -394,7 +425,8 @@ GList *lcat, *list;
 		case FLT_STATUS_UNCATEGORIZED:
 			flt->option[FILTER_CATEGORY] = 1;
 			catitem = da_cat_get(0);	// no category
-			catitem->filter = TRUE;
+			if(catitem != NULL)
+				catitem->filter = TRUE;
 			break;
 
 		case FLT_STATUS_UNRECONCILED:
@@ -465,6 +497,13 @@ gchar *tags;
 
 	if(flags & FLT_QSEARCH_MEMO)
 	{
+		//#1668036 always try match on txn memo first
+		if(txn->wording)
+		{
+			retval |= filter_text_compare(txn->wording, needle, FALSE);
+		}
+		if(retval) goto end;
+		
 		//#1509485
 		if(txn->flags & OF_SPLIT)
 		{
@@ -483,13 +522,6 @@ gchar *tags;
 					break;
 			}
 		}
-		else
-		{
-			if(txn->wording)
-			{
-				retval |= filter_text_compare(txn->wording, needle, FALSE);
-			}
-		}
 		if(retval) goto end;
 	}
 	
@@ -597,7 +629,7 @@ gint insert;
 
 /* date */
 	if(flt->option[FILTER_DATE]) {
-		insert = ( (txn->date >= flt->mindate) && (txn->date <= flt->maxdate) ) ? 1 : 0;
+		insert = ( (txn->date >= flt->mindate) && (txn->date <= (flt->maxdate + flt->nbdaysfuture) ) ) ? 1 : 0;
 		if(flt->option[FILTER_DATE] == 2) insert ^= 1;
 	}
 	if(!insert) goto end;
@@ -707,7 +739,13 @@ gint insert;
 
 		if(flt->wording)
 		{
-			if(txn->flags & OF_SPLIT)
+			//#1668036 always try match on txn memo first
+			if(txn->wording)
+			{
+				insert2 = filter_text_compare(txn->wording, flt->wording, flt->exact);
+			}
+
+			if( (insert2 == 0) && (txn->flags & OF_SPLIT) )
 			{
 			guint count, i;
 			Split *split;
@@ -724,13 +762,6 @@ gint insert;
 						break;
 				}
 			}
-			else
-			{
-				if(txn->wording)
-				{
-					insert2 = filter_text_compare(txn->wording, flt->wording, flt->exact);
-				}
-			}
 		}
 		else
 			insert2 = 1;
