@@ -94,6 +94,7 @@ typedef struct _filter	Filter;
 struct _filter
 {
 	guint32		mindate, maxdate;
+	gint		nbdaysfuture;
 	gint		range;
 	gint		type;
 	gint		status;
@@ -110,7 +111,7 @@ struct _filter
 	gchar		*info;
 	gchar		*wording;
 	gchar		*tag;
-	guint		last_tab;
+	gchar		last_tab[8];
 };
 
 
