@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2016 Maxime DOYEN
+ *  Copyright (C) 1995-2017 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -21,18 +21,6 @@
 #define __HB_IMPORT_H__
 
 
-
-
-typedef struct _OfxContext OfxContext;
-struct _OfxContext
-{
-	GList		*trans_list;
-	Account 	*curr_acc;
-	gboolean	curr_acc_isnew;
-};
-
-
-
 typedef struct _ImportContext ImportContext;
 struct _ImportContext
 {
@@ -50,6 +38,17 @@ struct _ImportContext
 	gint			nb_duplicate;
 };
 
+
+typedef struct _OfxContext OfxContext;
+struct _OfxContext
+{
+	GList		*trans_list;
+	Account 	*curr_acc;
+	gboolean	curr_acc_isnew;
+	ImportContext *ictx;
+};
+
+
 typedef struct _QifContext QifContext;
 typedef struct _qif_split	QIFSplit;
 typedef struct _qif_tran	QIF_Tran;
@@ -112,6 +111,9 @@ gdouble hb_qif_parser_get_amount(gchar *string);
 Account *import_create_account(gchar *name, gchar *number);
 GList *homebank_ofx_import(gchar *filename, ImportContext *ictx);
 
+gboolean hb_csv_row_valid(gchar **str_array, guint nbcolumns, gint *csvtype);
+gchar **hb_csv_row_get(gchar *string, gchar *delimiter, gint max_tokens);
+
 GList *homebank_csv_import(gchar *filename, ImportContext *ictx);
 
 #endif
