@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2015 Maxime DOYEN
+ *  Copyright (C) 1995-2017 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -20,8 +20,6 @@
 #ifndef __HB_XML_H__
 #define __HB_XML_H__
 
-gint homebank_load_xml(gchar *filename);
-gint homebank_save_xml(gchar *filename);
 
 enum
 {
@@ -33,4 +31,16 @@ enum
 };
 
 
+typedef struct _ParseContext ParseContext;
+struct _ParseContext
+{
+	gdouble	file_version;	//version of the xml structure
+	gint	data_version;   //last hb version file was saved with
+};
+
+
+gint homebank_load_xml(gchar *filename);
+gint homebank_save_xml(gchar *filename);
+
+
 #endif
