@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2016 Maxime DOYEN
+ *  Copyright (C) 1995-2017 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -42,7 +42,7 @@ enum
 
 struct repbalance_data
 {
-	GQueue		*txn_queue;
+	GList		*ope_list;
 	Filter		*filter;
 
 	guint32		accnum;
