@@ -47,6 +47,9 @@ struct assist_start_data *data = user_data;
 Account *item;
 gdouble value;
 
+	DB( g_print("\n[ui-start] apply\n") );
+
+
 	/* set owner */
 	gchar *owner = (gchar *)gtk_entry_get_text(GTK_ENTRY(data->ST_owner));
 	if (owner && *owner)
@@ -98,6 +101,8 @@ gdouble value;
 	GLOBALS->changes_count++;
 
 	//our global list has changed, so update the treeview
+	//todo: #1693998 crappy to do this here
+	account_compute_balances ();
 	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE+UF_BALANCE+UF_REFRESHALL));
 
 }
@@ -107,6 +112,9 @@ on_assistant_close_cancel (GtkWidget *widget, gpointer user_data)
 {
 struct assist_start_data *data = user_data;
 
+	DB( g_print("\n[ui-start] close/cancel\n") );
+
+
 	//data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 	gtk_widget_destroy (data->window);
 
@@ -123,6 +131,9 @@ struct assist_start_data *data = user_data;
 	gint current_page, n_pages;
   gchar *title;
 
+	DB( g_print("\n[ui-start] prepare\n") );
+
+
   current_page = gtk_assistant_get_current_page (GTK_ASSISTANT (widget));
   n_pages = gtk_assistant_get_n_pages (GTK_ASSISTANT (widget));
 
@@ -226,6 +237,9 @@ ui_start_assistant_property_fill (GtkWidget *assistant, struct assist_start_data
 Currency *cur;
 gchar label[128];
 
+	DB( g_print("\n[ui-start] property_fill\n") );
+
+
 	gtk_entry_set_text(GTK_ENTRY(data->ST_owner), g_get_real_name ());
 
 	cur = da_cur_get (GLOBALS->kcur);
@@ -443,6 +457,9 @@ ui_start_assistant (void)
 struct assist_start_data *data;
 GtkWidget *assistant, *page;
 
+	DB( g_print("\n[ui-start] new\n") );
+
+
 	data = g_malloc0(sizeof(struct assist_start_data));
 	if(!data) return NULL;
 
